@@ -1,7 +1,7 @@
 """Tests for the context utility functions."""
 from django.test import TestCase
 
-from ..context.utils import append_overhead_costs, get_counter
+from ..context.utils import append_overhead_costs, get_counter, get_sprints
 
 
 class AppendOverheadCostsTestCase(TestCase):
@@ -38,3 +38,15 @@ class GetCounterTestCase(TestCase):
         self.assertEqual(counter[0], 0, msg=(
             'The function should change the list and increase the value by'
             ' one.'))
+
+
+class GetSprintsTestCase(TestCase):
+    """Tests for the ``get_sprints`` function."""
+    longMessage = True
+
+    def test_function(self):
+        result = get_sprints()
+        self.assertEqual(result[0]['id'], 1, msg=(
+            'Should return the first sprint as set up in the test_app'))
+        self.assertEqual(result[0]['tasks'][0]['id'], 100, msg=(
+            'Should add the tasks that belong to this sprint'))
